 /********************************************************************
*   A7169CONFIG.h
*   RF Chip-A7169 Configure Definitions
*
*   This file provides the constants associated with the
*   AMICCOM A7169 device.
*
********************************************************************/
#ifndef _A7169CONFIG_h_
#define _A7169CONFIG_h_
#include <stdint.h>
#define DR_10Kbps_50KIFBW       //433MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
// #define DR_10Kbps_100KIFBW      //433MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
//#define DR_50Kbps_50KIFBW       //433MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
// #define DR_100Kbps_100KIFBW     //433MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
//#define DR_250Kbps_250KIFBW     //433MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
//#define DR_500Kbps_500KIFBW     //433MHz, 500kbps (IFBW = 500KHz, Fdev = 187.5KHz), Crystal=16MHz


#ifdef DR_10Kbps_50KIFBW

uint16_t A7169Config[]=        //433MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0803,     //SYSTEM CLOCK register,
    0x0821,     //PLL1 register,
    0xDA05,     //PLL2 register,    433.301MHz
    0x0000,     //PLL3 register,
    0x0A20,     //PLL4 register,
    0x0000,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0025,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D0,     //RX1 register,     IFBW=50KHz  
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x6C00,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

uint16_t A7169Config_PageA[]=   //433MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0xF606,     //TX1 register,     Fdev = 18.75kHz
    0xFC00,     //WOR1 register,
    0xF811,     //WOR2 register,
    0x0907,     //RFI register,     Enable Tx Ramp up/down  
    0x8A10,     //PM register,      CST=1
    0x0303,     //RTH register,
    0x400F,     //AGC1 register,    
    0x0DC0,     //AGC2 register, 
    0x0001,     //GIO register,     GIO1=WTR
    0xFA01,     //CKO register
    0x0048,     //VCB register,
    0x6921,     //CHG1 register,    430MHz
    0x0F21,     //CHG2 register,    435MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x87E0      //WCAL register,
};

uint16_t A7169Config_PageB[]=   //433MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0337,     //TX2 register,
    0x8200,     //IF1 register,     Enable Auto-IF, IF=100KHz
    0x0000,     //IF2 register,
    0x0000,     //ACK register,
    0x0000,     //ART register,
    0x3800,     //SYN register,
    0xF177,     //RCCAL register,
    0x0000,     //ACKFIFO register,
    0x0064,     //PNCFG1 register,
    0x0010,     //PNCFG2 register,
    0x0001,     //PNCFG3 register,
    0x0000,		  //PNCFG4 register,
    0x0001,     //PNCFG5 register,
    0x0000,     //TCODE register,
    0x0000,     //PN DC register,
    0x0036,     //PNCFG6 register,
    0x0C24,     //PNCFG7 register,
    0xA521,     //PNCFG8 register,
    0xF045,     //PNCFG9 register,
    0x003F,     //PNCFG10 register,
    0x4442,     //Misc_CFG1 register,
    0x0729,     //Misc_CFG2 register,
    0x0040,     //Misc_CFG3 register,
    0x0021,     //PLL7 register,
    0xDA05,     //PLL8 register,
    0x0000,     //PS MODE1 register,
    0x0000,     //PS MODE2 register,
    0x0000,     //PS MODE3 register,
    0x0000,     //TX3 register,
    0x0060,     //Misc_CFG4 register,
    0x0000,     //PNCFG11 register,
    0x0000,     //PNCFG12 register,
    0x0000,     //PNCFG13 register,
    0x0000,     //PNCFG14 register,
    0x0000,     //PNCFG15 register,
    0x0000,     //PNCFG16 register,
    0x0000,     //PNCFG17 register,
    0x000F,     //PNCFG18 register,
    0x0000,     //CSMA1 register,
    0x0000,     //CSMA2 register,
    0x0000,     //TXPA register,
    0x0000,     //DCMON1 register,
    0x0000,     //DCMON2 register,
    0x0000,     //DCMON3 register,
    0x0000,     //MBUS1 register,
    0x0000,     //MBUS2 register,
    0x0000,     //MBUS3 register,
    0x0000,     //MBUS4 register,
    0x0000,     //MBUS5 register,
    0x0000,     //PN DC2 register,
    0x0000,     //VCB2 register,
    0x0000,     //PS MODE4 register
    0x0000     	//WOR3 register
};

#endif


#ifdef DR_10Kbps_100KIFBW

const uint16_t A7169Config[]=        //433MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x1201,     //SYSTEM CLOCK register,
    0x0821,     //PLL1 register,
    0xDA05,     //PLL2 register,    433.301MHz
    0x0000,     //PLL3 register,
    0x0A20,     //PLL4 register,
    0x0000,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0025,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D4,     //RX1 register,     IFBW=100KHz
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x6C00,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const uint16_t A7169Config_PageA[]=   //433MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0xF706,     //TX1 register,     Fdev = 37.5kHz
    0xFC00,     //WOR1 register,
    0xF811,     //WOR2 register,
    0x0907,     //RFI register,     Enable Tx Ramp up/down  
    0x8A10,     //PM register,
    0x0303,     //RTH register,
    0x400F,     //AGC1 register,    
    0x0DC0,     //AGC2 register, 
    0x0001,     //GIO register,     GIO1=WTR
    0xFA01,     //CKO register
    0x0004,     //VCB register,
    0x6921,     //CHG1 register,    430MHz
    0x0F21,     //CHG2 register,    435MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x87E0      //WCAL register,
};

const uint16_t A7169Config_PageB[]=   //433MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x0337,     //TX2 register,
    0x8400,     //IF1 register,     Enable Auto-IF, IF=200KHz
    0x0000,     //IF2 register,
    0x0000,     //ACK register,
    0x0000,     //ART register,
    0x3800,     //SYN register,
    0xF177,     //RCCAL register,
    0x0000,     //ACKFIFO register,
    0x0064,     //PNCFG1 register,
    0x0010,     //PNCFG2 register,
    0x0001,     //PNCFG3 register,
    0x0000,		  //PNCFG4 register,
    0x0001,     //PNCFG5 register,
    0x0000,     //TCODE register,
    0x0000,     //PN DC register,
    0x0036,     //PNCFG6 register,
    0x0C24,     //PNCFG7 register,
    0xA521,     //PNCFG8 register,
    0xF045,     //PNCFG9 register,
    0x003F,     //PNCFG10 register,
    0x4442,     //Misc_CFG1 register,
    0x0729,     //Misc_CFG2 register,
    0x0040,     //Misc_CFG3 register,
    0x0021,     //PLL7 register,
    0xDA05,     //PLL8 register,
    0x0000,     //PS MODE1 register,
    0x0000,     //PS MODE2 register,
    0x0000,     //PS MODE3 register,
    0x0000,     //TX3 register,
    0x0060,     //Misc_CFG4 register,
    0x0000,     //PNCFG11 register,
    0x0000,     //PNCFG12 register,
    0x0000,     //PNCFG13 register,
    0x0000,     //PNCFG14 register,
    0x0000,     //PNCFG15 register,
    0x0000,     //PNCFG16 register,
    0x0000,     //PNCFG17 register,
    0x000F,     //PNCFG18 register,
    0x0000,     //CSMA1 register,
    0x0000,     //CSMA2 register,
    0x0000,     //TXPA register,
    0x0000,     //DCMON1 register,
    0x0000,     //DCMON2 register,
    0x0000,     //DCMON3 register,
    0x0000,     //MBUS1 register,
    0x0000,     //MBUS2 register,
    0x0000,     //MBUS3 register,
    0x0000,     //MBUS4 register,
    0x0000,     //MBUS5 register,
    0x0000,     //PN DC2 register,
    0x0000,     //VCB2 register,
    0x0000,     //PS MODE4 register
    0x0000     	//WOR3 register
};

#endif


#ifdef DR_50Kbps_50KIFBW

const uint16_t A7169Config[]=        //433MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0003,     //SYSTEM CLOCK register,
    0x0821,     //PLL1 register,
    0xDA05,     //PLL2 register,    433.301MHz
    0x0000,     //PLL3 register,
    0x0A20,     //PLL4 register,
    0x0000,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0025,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D0,     //RX1 register,     IFBW=50KHz  
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x6C00,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const uint16_t A7169Config_PageA[]=   //433MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0xF606,     //TX1 register,     Fdev = 18.75kHz
    0xFC00,     //WOR1 register,
    0xF811,     //WOR2 register,
    0x0907,     //RFI register,     Enable Tx Ramp up/down  
    0x8A10,     //PM register,      CST=1
    0x0303,     //RTH register,
    0x400F,     //AGC1 register,    
    0x0DC0,     //AGC2 register, 
    0x0001,     //GIO register,     GIO1=WTR
    0xFA01,     //CKO register
    0x0048,     //VCB register,
    0x6921,     //CHG1 register,    430MHz
    0x0F21,     //CHG2 register,    435MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x87E0      //WCAL register,
};

const uint16_t A7169Config_PageB[]=   //433MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0337,     //TX2 register,
    0x8200,     //IF1 register,     Enable Auto-IF, IF=100KHz
    0x0000,     //IF2 register,
    0x0000,     //ACK register,
    0x0000,     //ART register,
    0x3800,     //SYN register,
    0xF177,     //RCCAL register,
    0x0000,     //ACKFIFO register,
    0x0064,     //PNCFG1 register,
    0x0010,     //PNCFG2 register,
    0x0001,     //PNCFG3 register,
    0x0000,		  //PNCFG4 register,
    0x0001,     //PNCFG5 register,
    0x0000,     //TCODE register,
    0x0000,     //PN DC register,
    0x0036,     //PNCFG6 register,
    0x0C24,     //PNCFG7 register,
    0xA521,     //PNCFG8 register,
    0xF045,     //PNCFG9 register,
    0x003F,     //PNCFG10 register,
    0x4442,     //Misc_CFG1 register,
    0x0729,     //Misc_CFG2 register,
    0x0040,     //Misc_CFG3 register,
    0x0021,     //PLL7 register,
    0xDA05,     //PLL8 register,
    0x0000,     //PS MODE1 register,
    0x0000,     //PS MODE2 register,
    0x0000,     //PS MODE3 register,
    0x0000,     //TX3 register,
    0x0060,     //Misc_CFG4 register,
    0x0000,     //PNCFG11 register,
    0x0000,     //PNCFG12 register,
    0x0000,     //PNCFG13 register,
    0x0000,     //PNCFG14 register,
    0x0000,     //PNCFG15 register,
    0x0000,     //PNCFG16 register,
    0x0000,     //PNCFG17 register,
    0x000F,     //PNCFG18 register,
    0x0000,     //CSMA1 register,
    0x0000,     //CSMA2 register,
    0x0000,     //TXPA register,
    0x0000,     //DCMON1 register,
    0x0000,     //DCMON2 register,
    0x0000,     //DCMON3 register,
    0x0000,     //MBUS1 register,
    0x0000,     //MBUS2 register,
    0x0000,     //MBUS3 register,
    0x0000,     //MBUS4 register,
    0x0000,     //MBUS5 register,
    0x0000,     //PN DC2 register,
    0x0000,     //VCB2 register,
    0x0000,     //PS MODE4 register
    0x0000     	//WOR3 register
};

#endif


#ifdef DR_100Kbps_100KIFBW

const uint16_t A7169Config[]=        //433MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x0001,     //SYSTEM CLOCK register,
    0x0821,     //PLL1 register,
    0xDA05,     //PLL2 register,    433.301MHz
    0x0000,     //PLL3 register,
    0x0A20,     //PLL4 register,
    0x0000,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0025,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D4,     //RX1 register,     IFBW=100KHz
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x6C00,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const uint16_t A7169Config_PageA[]=   //433MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0xF706,     //TX1 register,     Fdev = 37.5kHz
    0xFC00,     //WOR1 register,
    0xF811,     //WOR2 register,
    0x0907,     //RFI register,     Enable Tx Ramp up/down  
    0x8A10,     //PM register,
    0x0303,     //RTH register,
    0x400F,     //AGC1 register,    
    0x0DC0,     //AGC2 register, 
    0x0001,     //GIO register,     GIO1=WTR
    0xFA01,     //CKO register
    0x0004,     //VCB register,
    0x6921,     //CHG1 register,    430MHz
    0x0F21,     //CHG2 register,    435MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x87E0      //WCAL register,
};

const uint16_t A7169Config_PageB[]=   //433MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x0337,     //TX2 register,
    0x8400,     //IF1 register,     Enable Auto-IF, IF=200KHz
    0x0000,     //IF2 register,
    0x0000,     //ACK register,
    0x0000,     //ART register,
    0x3800,     //SYN register,
    0xF177,     //RCCAL register,
    0x0000,     //ACKFIFO register,
    0x0064,     //PNCFG1 register,
    0x0010,     //PNCFG2 register,
    0x0001,     //PNCFG3 register,
    0x0000,		  //PNCFG4 register,
    0x0001,     //PNCFG5 register,
    0x0000,     //TCODE register,
    0x0000,     //PN DC register,
    0x0036,     //PNCFG6 register,
    0x0C24,     //PNCFG7 register,
    0xA521,     //PNCFG8 register,
    0xF045,     //PNCFG9 register,
    0x003F,     //PNCFG10 register,
    0x4442,     //Misc_CFG1 register,
    0x0729,     //Misc_CFG2 register,
    0x0040,     //Misc_CFG3 register,
    0x0021,     //PLL7 register,
    0xDA05,     //PLL8 register,
    0x0000,     //PS MODE1 register,
    0x0000,     //PS MODE2 register,
    0x0000,     //PS MODE3 register,
    0x0000,     //TX3 register,
    0x0060,     //Misc_CFG4 register,
    0x0000,     //PNCFG11 register,
    0x0000,     //PNCFG12 register,
    0x0000,     //PNCFG13 register,
    0x0000,     //PNCFG14 register,
    0x0000,     //PNCFG15 register,
    0x0000,     //PNCFG16 register,
    0x0000,     //PNCFG17 register,
    0x000F,     //PNCFG18 register,
    0x0000,     //CSMA1 register,
    0x0000,     //CSMA2 register,
    0x0000,     //TXPA register,
    0x0000,     //DCMON1 register,
    0x0000,     //DCMON2 register,
    0x0000,     //DCMON3 register,
    0x0000,     //MBUS1 register,
    0x0000,     //MBUS2 register,
    0x0000,     //MBUS3 register,
    0x0000,     //MBUS4 register,
    0x0000,     //MBUS5 register,
    0x0000,     //PN DC2 register,
    0x0000,     //VCB2 register,
    0x0000,     //PS MODE4 register
    0x0000     	//WOR3 register
};

#endif


#ifdef DR_250Kbps_250KIFBW

const uint16_t A7169Config[]=        //433MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
{
    0x0000,     //SYSTEM CLOCK register,
    0x381B,     //PLL1 register,
    0x14D0,     //PLL2 register,    433.301MHz
    0x0000,     //PLL3 register,
    0x0A20,     //PLL4 register,
    0x0000,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0025,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18DC,     //RX1 register,     IFBW=250KHz 
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x6C00,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const uint16_t A7169Config_PageA[]=   //433MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
{
    0xF70C,     //TX1 register,     Fdev = 93.75kHz
    0xFC00,     //WOR1 register,
    0xF811,     //WOR2 register,
    0x0907,     //RFI register,     Enable Tx Ramp up/down  
    0x8A10,     //PM register,
    0x0303,     //RTH register,
    0x400F,     //AGC1 register,    
    0x0DC0,     //AGC2 register, 
    0x8001,     //GIO register,     GIO1=WTR
    0xFA01,     //CKO register
    0x0048,     //VCB register,
    0x6E1A,     //CHG1 register,    430MHz
    0x231B,     //CHG2 register,    435MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x9504,     //CODE register,    Preamble=16bytes, ID=4bytes
    0x87E0      //WCAL register,
};

const uint16_t A7169Config_PageB[]=   //433MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
{
    0x0337,     //TX2 register,
    0x8800,     //IF1 register,     Enable Auto-IF, IF=500KHz
    0x0000,     //IF2 register,
    0x0000,     //ACK register,
    0x0000,     //ART register,
    0x3800,     //SYN register,
    0xF177,     //RCCAL register,
    0x0000,     //ACKFIFO register,
    0x0064,     //PNCFG1 register,
    0x0010,     //PNCFG2 register,
    0x0001,     //PNCFG3 register,
    0x0000,		  //PNCFG4 register,
    0x0001,     //PNCFG5 register,
    0x0000,     //TCODE register,
    0x0000,     //PN DC register,
    0x0036,     //PNCFG6 register,
    0x0C24,     //PNCFG7 register,
    0xA521,     //PNCFG8 register,
    0xF045,     //PNCFG9 register,
    0x003F,     //PNCFG10 register,
    0x4443,     //Misc_CFG1 register,
    0x0729,     //Misc_CFG2 register,
    0x0040,     //Misc_CFG3 register,
    0x001D,     //PLL7 register,
    0x6004,     //PLL8 register,
    0x0000,     //PS MODE1 register,
    0x0000,     //PS MODE2 register,
    0x0000,     //PS MODE3 register,
    0x0000,     //TX3 register,
    0x0060,     //Misc_CFG4 register,
    0x0000,     //PNCFG11 register,
    0x0000,     //PNCFG12 register,
    0x0000,     //PNCFG13 register,
    0x0000,     //PNCFG14 register,
    0x0000,     //PNCFG15 register,
    0x0000,     //PNCFG16 register,
    0x0000,     //PNCFG17 register,
    0x000F,     //PNCFG18 register,
    0x0000,     //CSMA1 register,
    0x0000,     //CSMA2 register,
    0x0000,     //TXPA register,
    0x0000,     //DCMON1 register,
    0x0000,     //DCMON2 register,
    0x0000,     //DCMON3 register,
    0x0000,     //MBUS1 register,
    0x0000,     //MBUS2 register,
    0x0000,     //MBUS3 register,
    0x0000,     //MBUS4 register,
    0x0000,     //MBUS5 register,
    0x0000,     //PN DC2 register,
    0x0000,     //VCB2 register,
    0x0000,     //PS MODE4 register
    0x0000     	//WOR3 register
};

#endif


#ifdef DR_500Kbps_500KIFBW     

const uint16_t A7169Config[]=        //433MHz, 500kbps (IFBW = 500KHz, Fdev = 187.5KHz), Crystal=16MHz
{
    0x0000,     //SYSTEM CLOCK register,
    0x1C1B,     //PLL1 register,
    0x14D0,     //PLL2 register,    433.301MHz
    0x0000,     //PLL3 register,
    0x0A20,     //PLL4 register,
    0x0000,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0025,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18CC,     //RX1 register,     IFBW=250KHz 
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x6C00,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const uint16_t A7169Config_PageA[]=   //433MHz, 500kbps (IFBW = 500KHz, Fdev = 187.5KHz), Crystal=16MHz
{
    0xF718,     //TX1 register,     Fdev = 187.5kHz
    0xFC00,     //WOR1 register,
    0xF811,     //WOR2 register,
    0x0907,     //RFI register,     Enable Tx Ramp up/down  
    0x8A10,     //PM register,
    0x0303,     //RTH register,
    0x400F,     //AGC1 register,    
    0x0DC0,     //AGC2 register, 
    0x8001,     //GIO register,     GIO1=WTR
    0xFA01,     //CKO register
    0x0048,     //VCB register,
    0x6E1A,     //CHG1 register,    430MHz
    0x231B,     //CHG2 register,    435MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x9504,     //CODE register,    Preamble=16bytes, ID=4bytes
    0x87E0      //WCAL register,
};

const uint16_t A7169Config_PageB[]=   //433MHz, 500kbps (IFBW = 500KHz, Fdev = 187.5KHz), Crystal=16MHz
{
    0x0337,     //TX2 register,
    0x8800,     //IF1 register,     Enable Auto-IF, IF=500KHz
    0x0000,     //IF2 register,
    0x0000,     //ACK register,
    0x0000,     //ART register,
    0x3800,     //SYN register,
    0xF177,     //RCCAL register,
    0x0000,     //ACKFIFO register,
    0x0064,     //PNCFG1 register,
    0x0010,     //PNCFG2 register,
    0x0001,     //PNCFG3 register,
    0x0000,		  //PNCFG4 register,
    0x0001,     //PNCFG5 register,
    0x0000,     //TCODE register,
    0x0000,     //PN DC register,
    0x0036,     //PNCFG6 register,
    0x0C24,     //PNCFG7 register,
    0xA521,     //PNCFG8 register,
    0xF045,     //PNCFG9 register,
    0x003F,     //PNCFG10 register,
    0x4443,     //Misc_CFG1 register,
    0x0729,     //Misc_CFG2 register,
    0x0050,     //Misc_CFG3 register,
    0x001B,     //PLL7 register,
    0x14D0,     //PLL8 register,
    0x0000,     //PS MODE1 register,
    0x0000,     //PS MODE2 register,
    0x0000,     //PS MODE3 register,
    0x0000,     //TX3 register,
    0x0060,     //Misc_CFG4 register,
    0x0000,     //PNCFG11 register,
    0x0000,     //PNCFG12 register,
    0x0000,     //PNCFG13 register,
    0x0000,     //PNCFG14 register,
    0x0000,     //PNCFG15 register,
    0x0000,     //PNCFG16 register,
    0x0000,     //PNCFG17 register,
    0x000F,     //PNCFG18 register,
    0x0000,     //CSMA1 register,
    0x0000,     //CSMA2 register,
    0x0000,     //TXPA register,
    0x0000,     //DCMON1 register,
    0x0000,     //DCMON2 register,
    0x0000,     //DCMON3 register,
    0x0000,     //MBUS1 register,
    0x0000,     //MBUS2 register,
    0x0000,     //MBUS3 register,
    0x0000,     //MBUS4 register,
    0x0000,     //MBUS5 register,
    0x0000,     //PN DC2 register,
    0x0000,     //VCB2 register,
    0x0000,     //PS MODE4 register
    0x0000     	//WOR3 register
};

#endif


#endif